@@ -1,4 +1,4 @@
-// Copyright 2000-2020 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
+// Copyright 2000-2024 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
 package com.jetbrains.python.psi.stubs;
 
 import com.intellij.psi.stubs.NamedStub;
@@ -9,8 +9,7 @@ public interface PyNamedParameterStub extends NamedStub<PyNamedParameter>, PyAnn
   boolean isPositionalContainer();
   boolean isKeywordContainer();
 
-  @Nullable
-  default String getDefaultValueText() {
+  default @Nullable String getDefaultValueText() {
     return null;
   }
 }
\ No newline at end of file
